LABELS = {
    'TBR': '#AD8D43',
    'Backlog': '#5843AD',
    'Critical': '#FF0000',
    'Blocked': '#FF0000',
    'High': '#D9534F',
    'Bug': '#D9534F',
    'Feature': '#0033CC',
    'Rework': '#F0AD4E',
    'Medium': '#D1D100',
    'Documentation': '#7F8C8D',
    'Review': '#0033CC',
    'To Do': '#F0AD4E',
    'Doing': '#5CB85C',
    'Low': '#44AD8E',
    'Ready': '#00b140',
    'Redacted': '#0000ff',
    'Selected': '#6699cc'
}

BOARDS = {
    'Developement': [ 'Backlog', 'Doing', 'Review', 'Blocked'     ],
    'Priority':     [ 'Low', 'Medium', 'High', 'Critical'         ],
    'Readiness':    [ 'Selected', 'Redacted', 'Ready', 'Backlog'  ],
    'Types':        [ 'Feature', 'Bug', 'Rework', 'Documentation' ]
}
